==> aria2_1.10.0.orig.tar.gz: aria2-1.10.0/src/SpeedCalc.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef _D_SPEED_CALC_H_
#define _D_SPEED_CALC_H_

#include "common.h"
#include "TimerA2.h"

namespace aria2 {

class SpeedCalc {
private:
  uint64_t lengthArray_[2];
  int sw_;
  Timer cpArray_[2];
  unsigned int maxSpeed_;
  unsigned int prevSpeed_;
  Timer start_;
  uint64_t accumulatedLength_;
  time_t nextInterval_;

  bool isIntervalOver() const;

  bool isIntervalOver(int64_t milliElapsed) const;

  void changeSw();
public:
  SpeedCalc();

  /**
   * Returns download/upload speed in byte per sec
   */
  unsigned int calculateSpeed();

  unsigned int getMaxSpeed() const {
    return maxSpeed_;
  }

  unsigned int calculateAvgSpeed() const;

  void update(size_t bytes);

  void reset();
};

} // namespace aria2

#endif // _D_SPEED_CALC_H_

==> aria2_1.21.0.orig.tar.gz: aria2-1.21.0/src/SpeedCalc.h <==
/* <!-- copyright */
/*
 * aria2 - The high speed download utility
 *
 * Copyright (C) 2006 Tatsuhiro Tsujikawa
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
/* copyright --> */
#ifndef D_SPEED_CALC_H
#define D_SPEED_CALC_H

#include "common.h"

#include <deque>

#include "TimerA2.h"

namespace aria2 {

class SpeedCalc {
private:
  std::deque<std::pair<Timer, size_t>> timeSlots_;
  Timer start_;
  int64_t accumulatedLength_;
  int64_t bytesWindow_;
  int maxSpeed_;

  void removeStaleTimeSlot(const Timer& now);

public:
  SpeedCalc();

  /**
   * Returns download/upload speed in byte per sec
   */
  int calculateSpeed();

  int getMaxSpeed() const { return maxSpeed_; }

  int calculateAvgSpeed() const;

  void update(size_t bytes);

  void reset();
};

} // namespace aria2

#endif // D_SPEED_CALC_H
